@@ -1,6 +1,6 @@
 /* libSoX Library Public Interface
  *
- * Copyright 1999-2011 Chris Bagwell and SoX Contributors.
+ * Copyright 1999-2012 Chris Bagwell and SoX Contributors.
  *
  * This source code is freely redistributable and may be used for
  * any purpose.  This copyright notice must be maintained.
@@ -44,7 +44,7 @@ Plugins API:
 Attribute required on all functions exported by libSoX and on all function
 pointer types used by the libSoX API.
 */
-#ifdef __GNUC__
+#if defined(__GNUC__) && defined(__i386)
 #define LSX_API  __attribute__ ((cdecl)) /* libSoX function */
 #elif _MSC_VER
 #define LSX_API  __cdecl /* libSoX function */
@@ -516,6 +516,7 @@ Client API:
 Boolean type, assignment (but not necessarily binary) compatible with C++ bool.
 */
 typedef enum sox_bool {
+    sox_bool_dummy = -1, /* Ensure a signed type */
     sox_false, /**< False = 0. */
     sox_true   /**< True = 1. */
 } sox_bool;
@@ -592,6 +593,7 @@ typedef enum sox_encoding_t {
   SOX_ENCODING_AMR_NB    , /**< AMR-NB compression */
   SOX_ENCODING_CVSD      , /**< Continuously Variable Slope Delta modulation */
   SOX_ENCODING_LPC10     , /**< Linear Predictive Coding */
+  SOX_ENCODING_OPUS      , /**< Opus compression */
 
   SOX_ENCODINGS            /**< End of list marker */
 } sox_encoding_t;
@@ -661,7 +663,7 @@ The API version of the sox.h file. It is not meant to follow the version
 number of SoX but it has historically. Please do not count on
 SOX_LIB_VERSION_CODE staying in sync with the libSoX version.
 */
-#define SOX_LIB_VERSION_CODE   SOX_LIB_VERSION(14, 4, 1)
+#define SOX_LIB_VERSION_CODE   SOX_LIB_VERSION(14, 4, 2)
 
 /**
 Client API:
@@ -976,7 +978,7 @@ Converts SoX native sample to a 32-bit float.
 @param d Input sample to be converted.
 @param clips Variable to increment if input sample is too large.
 */
-#define SOX_SAMPLE_TO_FLOAT_32BIT(d,clips) (LSX_USE_VAR(sox_macro_temp_double),sox_macro_temp_sample=(d),sox_macro_temp_sample>SOX_SAMPLE_MAX-128?++(clips),1:(((sox_macro_temp_sample+128)&~255)*(1./(SOX_SAMPLE_MAX+1.))))
+#define SOX_SAMPLE_TO_FLOAT_32BIT(d,clips) (LSX_USE_VAR(sox_macro_temp_double),sox_macro_temp_sample=(d),sox_macro_temp_sample>SOX_SAMPLE_MAX-64?++(clips),1:(((sox_macro_temp_sample+64)&~127)*(1./(SOX_SAMPLE_MAX+1.))))
 
 /**
 Client API:
@@ -1117,10 +1119,10 @@ Callback to write a message to an output device (console or log file),
 used by sox_globals_t.output_message_handler.
 */
 typedef void (LSX_API * sox_output_message_handler_t)(
-    unsigned level,                       /* 1 = FAIL, 2 = WARN, 3 = INFO, 4 = DEBUG, 5 = DEBUG_MORE, 6 = DEBUG_MOST. */
-    LSX_PARAM_IN_Z char const * filename, /* Source code __FILENAME__ from which message originates. */
-    LSX_PARAM_IN_PRINTF char const * fmt, /* Message format string. */
-    LSX_PARAM_IN va_list ap               /* Message format parameters. */
+    unsigned level,                       /**< 1 = FAIL, 2 = WARN, 3 = INFO, 4 = DEBUG, 5 = DEBUG_MORE, 6 = DEBUG_MOST. */
+    LSX_PARAM_IN_Z char const * filename, /**< Source code __FILENAME__ from which message originates. */
+    LSX_PARAM_IN_PRINTF char const * fmt, /**< Message format string. */
+    LSX_PARAM_IN va_list ap               /**< Message format parameters. */
     );
 
 /**
@@ -1357,6 +1359,12 @@ typedef struct sox_globals_t {
   char       * tmp_path;         /**< Private: client-configured path to use for temporary files */
   sox_bool     use_magic;        /**< Private: true if client has requested use of 'magic' file-type detection */
   sox_bool     use_threads;      /**< Private: true if client has requested parallel effects processing */
+
+  /**
+  Log to base 2 of minimum size (in bytes) used by libSoX for DFT (filtering).
+  Plugins should use similarly-sized DFTs to get best performance.
+  */
+  size_t       log2_dft_min_size;
 } sox_globals_t;
 
 /**
@@ -1603,14 +1611,15 @@ struct sox_effect_t {
   sox_encodinginfo_t       const * in_encoding;  /**< Information about the incoming data encoding */
   sox_encodinginfo_t       const * out_encoding; /**< Information about the outgoing data encoding */
   sox_effect_handler_t     handler;   /**< The handler for this effect */
-  sox_sample_t             * obuf;    /**< output buffer */
-  size_t                   obeg;      /**< output buffer: start of valid data section */
-  size_t                   oend;      /**< output buffer: one past valid data section (oend-obeg is length of current content) */
-  size_t               imin;          /**< minimum input buffer content required for calling this effect's flow function; set via lsx_effect_set_imin() */
   sox_uint64_t         clips;         /**< increment if clipping occurs */
   size_t               flows;         /**< 1 if MCHAN, number of chans otherwise */
   size_t               flow;          /**< flow number */
   void                 * priv;        /**< Effect's private data area (each flow has a separate copy) */
+  /* The following items are private to the libSoX effects chain functions. */
+  sox_sample_t             * obuf;    /**< output buffer */
+  size_t                   obeg;      /**< output buffer: start of valid data section */
+  size_t                   oend;      /**< output buffer: one past valid data section (oend-obeg is length of current content) */
+  size_t               imin;          /**< minimum input buffer content required for calling this effect's flow function; set via lsx_effect_set_imin() */
 };
 
 /**
@@ -1619,13 +1628,13 @@ Chain of effects to be applied to a stream.
 */
 typedef struct sox_effects_chain_t {
   sox_effect_t **effects;                  /**< Table of effects to be applied to a stream */
-  unsigned table_size;                     /**< Number of entries in effects table */
-  unsigned length;                         /**< Number of effects to be applied */
-  sox_sample_t **ibufc;                    /**< Channel interleave buffer */
-  sox_sample_t **obufc;                    /**< Channel interleave buffer */
+  size_t length;                           /**< Number of effects to be applied */
   sox_effects_globals_t global_info;       /**< Copy of global effects settings */
   sox_encodinginfo_t const * in_enc;       /**< Input encoding */
   sox_encodinginfo_t const * out_enc;      /**< Output encoding */
+  /* The following items are private to the libSoX effects chain functions. */
+  size_t table_size;                       /**< Size of effects table (including unused entries) */
+  sox_sample_t *il_buf;                    /**< Channel interleave buffer */
 } sox_effects_chain_t;
 
 /*****************************************************************************
@@ -2599,6 +2608,17 @@ lsx_getopt(
     LSX_PARAM_INOUT lsx_getopt_t * state /**< The getopt state pointer. */
     );
 
+/**
+Plugins API:
+Gets the file length, or 0 if the file is not seekable/normal.
+@returns The file length, or 0 if the file is not seekable/normal.
+*/
+sox_uint64_t
+LSX_API
+lsx_filelength(
+    LSX_PARAM_IN sox_format_t * ft
+    );
+
 /* WARNING END */
 
 #if defined(__cplusplus)
